@@ -255,8 +255,7 @@ def test_mypy_indirect(testdir, xdist_args):
     testdir.makepyfile(good='''
         import bad
     ''')
-    xdist_args.append('good.py')  # Nothing may come after xdist_args in py34.
-    result = testdir.runpytest_subprocess('--mypy', *xdist_args)
+    result = testdir.runpytest_subprocess('--mypy', *xdist_args, 'good.py')
     assert result.ret != 0
 
 
@@ -280,10 +279,57 @@ def test_mypy_indirect_inject(testdir, xdist_args):
         def pytest_collection_modifyitems(session, config, items):
             plugin = config.pluginmanager.getplugin('mypy')
             items.append(
-                plugin.MypyFileItem(py.path.local('good.py'), session),
+                plugin.MypyFileItem.from_parent(
+                    parent=session,
+                    name=str(py.path.local('good.py')),
+                ),
             )
     ''')
-    testdir.mkdir('empty')
-    xdist_args.append('empty')  # Nothing may come after xdist_args in py34.
+    name = 'empty'
+    testdir.mkdir(name)
+    result = testdir.runpytest_subprocess('--mypy', *xdist_args, name)
+    assert result.ret != 0
+
+
+def test_api_error_formatter(testdir, xdist_args):
+    """Ensure that the plugin can be configured in a conftest.py."""
+    testdir.makepyfile(bad='''
+        def pyfunc(x: int) -> str:
+            return x * 2
+    ''')
+    testdir.makepyfile(conftest='''
+        def custom_file_error_formatter(item, results, errors):
+            return '\\n'.join(
+                '{path}:{error}'.format(
+                    path=item.fspath,
+                    error=error,
+                )
+                for error in errors
+            )
+
+        def pytest_configure(config):
+            plugin = config.pluginmanager.getplugin('mypy')
+            plugin.file_error_formatter = custom_file_error_formatter
+    ''')
     result = testdir.runpytest_subprocess('--mypy', *xdist_args)
+    result.stdout.fnmatch_lines([
+        '*/bad.py:2: error: Incompatible return value*',
+    ])
+    assert result.ret != 0
+
+
+def test_setup_cfg(testdir, xdist_args):
+    """Ensure that the plugin allows configuration with setup.cfg."""
+    testdir.makefile('.cfg', setup='''
+        [mypy]
+        disallow_untyped_defs = True
+    ''')
+    testdir.makepyfile(conftest='''
+        def pyfunc(x):
+            return x * 2
+    ''')
+    result = testdir.runpytest_subprocess('--mypy', *xdist_args)
+    result.stdout.fnmatch_lines([
+        '1: error: Function is missing a type annotation',
+    ])
     assert result.ret != 0
